#
# Conditional build:
%bcond_without	ffmpeg			# build with ffmpeg for thumbnails and previews
%bcond_without	freeimage		# build with freeimage to manage thumbnails/previews
%bcond_without	fuse			# build megafuse
%bcond_without	libmediainfo	# build with libmediainfo for media file attributes

Summary:	Command Line Interactive and Scriptable Application to access MEGA
Name:		megacmd
Version:	1.0.0
Release:	3
# https://github.com/meganz/MEGAcmd/commit/b366c77370c277223be123e05e5ef15fafbce185#r31261647
License:	BSD 2-Clause "Simplified" License
Group:		Applications
Source0:	https://github.com/meganz/MEGAcmd/archive/%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	8af6215ce167b15b92f8683c4c1caa7c
Source1:	https://github.com/meganz/sdk/archive/f3a3b810/mega-sdk-v3.4.0-216-gf3a3b810.tar.gz
# Source1-md5:	dccc60aa2ac5680a719b74bc0968984f
Patch0:		libtool.patch
URL:		https://mega.nz/
%{?with_freeimage:BuildRequires:	FreeImage-devel}
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	c-ares-devel
BuildRequires:	cryptopp-devel
%{?with_ffmpeg:BuildRequires:	ffmpeg-devel}
%{?with_fuse:BuildRequires:	libfuse-devel}
%{?with_mediainfo:BuildRequires:	libmediainfo-devel}
BuildRequires:	libraw-devel
BuildRequires:	libsodium-devel
BuildRequires:	libstdc++-devel
BuildRequires:	libtool
BuildRequires:	libuv-devel
BuildRequires:	openssl-devel
BuildRequires:	pcre-cxx-devel
BuildRequires:	pcre-devel
BuildRequires:	pkgconfig
BuildRequires:	readline-devel
BuildRequires:	sqlite3-devel
BuildRequires:	zlib-devel
Requires:	%{name}-libs = %{version}-%{release}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
MEGAcmd provides non UI access to MEGA services. It intends to offer
all the functionality with your MEGA account via commands. It features
synchronization and backup of local folders into your MEGA account.

%package libs
Summary:	Shared libmega library
Group:		Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description libs
Shared libmega library.

%package devel
Summary:	Header files for %{name} library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki %{name}
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description devel
Header files for %{name} library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki %{name}.

%package fuse
Summary:	megafuse
Group:		Libraries

%description fuse
megafuse.

%prep
%setup -q -n MEGAcmd-%{version} -a1
mv sdk-*/* sdk
%patch0 -p1

%build
autoreconf -vif
%configure \
	ac_cv_prog_HAVE_CPPCHECK=/usr/bin/cppcheck \
	%{__with_without ffmpeg} \
	%{__with_without freeimage} \
	%{__with_without fuse} \
	%{__with_without libmediainfo} \
	--disable-silent-rules
%{__make}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} $RPM_BUILD_ROOT%{_libdir}/libmega.la

%clean
rm -rf $RPM_BUILD_ROOT

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc README.md LICENSE
/etc/bash_completion.d/megacmd_completion.sh
%attr(755,root,root) %{_bindir}/mega-attr
%attr(755,root,root) %{_bindir}/mega-backup
%attr(755,root,root) %{_bindir}/mega-cancel
%attr(755,root,root) %{_bindir}/mega-cd
%attr(755,root,root) %{_bindir}/mega-cmd
%attr(755,root,root) %{_bindir}/mega-cmd-server
%attr(755,root,root) %{_bindir}/mega-confirm
%attr(755,root,root) %{_bindir}/mega-confirmcancel
%attr(755,root,root) %{_bindir}/mega-cp
%attr(755,root,root) %{_bindir}/mega-debug
%attr(755,root,root) %{_bindir}/mega-deleteversions
%attr(755,root,root) %{_bindir}/mega-du
%attr(755,root,root) %{_bindir}/mega-errorcode
%attr(755,root,root) %{_bindir}/mega-exclude
%attr(755,root,root) %{_bindir}/mega-exec
%attr(755,root,root) %{_bindir}/mega-export
%attr(755,root,root) %{_bindir}/mega-find
%attr(755,root,root) %{_bindir}/mega-ftp
%attr(755,root,root) %{_bindir}/mega-get
%attr(755,root,root) %{_bindir}/mega-graphics
%attr(755,root,root) %{_bindir}/mega-help
%attr(755,root,root) %{_bindir}/mega-https
%attr(755,root,root) %{_bindir}/mega-import
%attr(755,root,root) %{_bindir}/mega-invite
%attr(755,root,root) %{_bindir}/mega-ipc
%attr(755,root,root) %{_bindir}/mega-killsession
%attr(755,root,root) %{_bindir}/mega-lcd
%attr(755,root,root) %{_bindir}/mega-log
%attr(755,root,root) %{_bindir}/mega-login
%attr(755,root,root) %{_bindir}/mega-logout
%attr(755,root,root) %{_bindir}/mega-lpwd
%attr(755,root,root) %{_bindir}/mega-ls
%attr(755,root,root) %{_bindir}/mega-mkdir
%attr(755,root,root) %{_bindir}/mega-mount
%attr(755,root,root) %{_bindir}/mega-mv
%attr(755,root,root) %{_bindir}/mega-passwd
%attr(755,root,root) %{_bindir}/mega-permissions
%attr(755,root,root) %{_bindir}/mega-preview
%attr(755,root,root) %{_bindir}/mega-put
%attr(755,root,root) %{_bindir}/mega-pwd
%attr(755,root,root) %{_bindir}/mega-quit
%attr(755,root,root) %{_bindir}/mega-reload
%attr(755,root,root) %{_bindir}/mega-rm
%attr(755,root,root) %{_bindir}/mega-session
%attr(755,root,root) %{_bindir}/mega-share
%attr(755,root,root) %{_bindir}/mega-showpcr
%attr(755,root,root) %{_bindir}/mega-signup
%attr(755,root,root) %{_bindir}/mega-speedlimit
%attr(755,root,root) %{_bindir}/mega-sync
%attr(755,root,root) %{_bindir}/mega-thumbnail
%attr(755,root,root) %{_bindir}/mega-transfers
%attr(755,root,root) %{_bindir}/mega-userattr
%attr(755,root,root) %{_bindir}/mega-users
%attr(755,root,root) %{_bindir}/mega-version
%attr(755,root,root) %{_bindir}/mega-webdav
%attr(755,root,root) %{_bindir}/mega-whoami
%attr(755,root,root) %{_bindir}/megacli
%attr(755,root,root) %{_bindir}/megasimplesync

%if %{with fuse}
%files fuse
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/megafuse
%endif

%files libs
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libmega.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libmega.so.30401

%files devel
%defattr(644,root,root,755)
%{_includedir}/mega
%{_includedir}/mega.h
%{_includedir}/megaapi.h
%{_includedir}/megaapi_impl.h
%{_libdir}/libmega.so
%{_pkgconfigdir}/libmega.pc
%changelog
* Mon Dec 31 2018 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/megacmd.git;a=log;h=master

* Mon Dec 31 2018 Jan Rękorajski <baggins@pld-linux.org> b6559a1
- release 3 (by relup.sh)

* Tue Nov 27 2018 Elan Ruusamäe <glen@pld-linux.org> c0c97be
- add upstream links to libtool patches

* Tue Nov 27 2018 Elan Ruusamäe <glen@pld-linux.org> bceb490
- libtool patch needed also for main project

* Tue Nov 27 2018 Elan Ruusamäe <glen@pld-linux.org> e03499d
- add freeimage bcond

* Tue Nov 27 2018 Elan Ruusamäe <glen@pld-linux.org> f7ed37d
- bcond to build without ffmpeg

* Tue Nov 27 2018 Elan Ruusamäe <glen@pld-linux.org> cce502d
- do not depend on cppcheck

* Tue Nov 27 2018 Elan Ruusamäe <glen@pld-linux.org> 7b4a00e
- add libmediainfo bcond (libzen is it's dependency)

* Tue Nov 27 2018 Elan Ruusamäe <glen@pld-linux.org> 6773bcd
- correct with/without macro

* Tue Nov 27 2018 Elan Ruusamäe <glen@delfi.ee> e449691
- split megafuse

* Tue Nov 27 2018 Elan Ruusamäe <glen@delfi.ee> b33e795
- updaet BR with cleanbuild

* Mon Nov 12 2018 Elan Ruusamäe <glen@pld-linux.org> c1b11ad
- update license name

* Thu Nov 08 2018 Elan Ruusamäe <glen@pld-linux.org> f3c91bd
- fix library packaging

* Thu Nov 08 2018 Elan Ruusamäe <glen@pld-linux.org> 8e4e3a4
- up to 1.0.0

* Thu Nov 08 2018 Elan Ruusamäe <glen@pld-linux.org> a38be19
- up to 1.0.0

* Sun Mar 18 2018 Elan Ruusamäe <glen@pld-linux.org> 8eb3178
- patch sdk for libtool

* Sat Mar 17 2018 Elan Ruusamäe <glen@pld-linux.org> 87cee7c
- new, version 0.9.8

